@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: LimitPath.pm,v 1.31 2010-11-26 20:59:43 dpchrist Exp $
+# $Id: LimitPath.pm,v 1.32 2010-11-27 03:37:58 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -21,7 +21,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.31 $=~/: (\d+)\.(\d+)/;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.32 $=~/: (\d+)\.(\d+)/;
 
 #######################################################################
 # uses:
@@ -111,7 +111,7 @@ Dpchrist::File::LimitPath - limit path lengths
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.31 $.
+This documentation describes module revision $Revision: 1.32 $.
 
 
 This is alpha test level software
@@ -338,23 +338,30 @@ See 'perldoc Export' for everything in between.
 
 Old school:
 
-    perl Makefile.PL
-    make
-    make test
-    make install
+    $ perl Makefile.PL
+    $ make
+    $ make test
+    $ make install
 
 Minimal:
 
-    cpan Dpchrist::File::LimitPath
+    $ cpan Dpchrist::File::LimitPath
 
 Complete:
 
-    cpan Bundle::Dpchrist
+    $ cpan Bundle::Dpchrist
+
+The following warning may be safely ignored:
+
+    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
+    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
+    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
+    /usr/local/lib/site_perl .) at Makefile.PL line 22.
 
 
-=head1 DEPENDENCIES
+=head2 PREREQUISITES
 
-    See Makefile.PL in source distribution root directory.
+See Makefile.PL in the source distribution root directory.
 
 
 =head1 SEE ALSO
